@@ -207,12 +207,11 @@ class SqleeColumn:
         """ Usage: sync() """
         self.datas = [self.index_data, ]
 
-        datas = json.loads(self.table.crypto.decrypt_by_str(
+        self.datas += json.loads(self.table.crypto.decrypt_by_str(
             self.repo.get_file(path=self.path)
             ))
 
-        self.datas += datas
-        for data in datas:
+        for data in self.datas:
             setattr(self, self.namespace[datas.index(data)], data)
 
         if len(self.datas) != len(self.namespace):
